﻿using System;
using System.Configuration;

namespace HelloUnity.IoC
{
    /// <summary>
    /// 解析器工厂
    /// </summary>
    public class DependencyResolverFactory : IDependencyResolverFactory
    {
        private readonly Type _resolverType;

        public DependencyResolverFactory(string resolverTypeName)
        {
            _resolverType = Type.GetType(resolverTypeName, true, true);
        }

        public DependencyResolverFactory()
            : this(ConfigurationManager.AppSettings["dependencyResolverTypeName"])
        {

        }

        /// <summary>
        /// 创建特定解析器
        /// </summary>
        /// <returns></returns>
        public IDependencyResolver CreateInstance()
        {
            return Activator.CreateInstance(_resolverType) as IDependencyResolver;
        }
    }
}
